.. _pagetemplate_api_module:

:mod:`z3c.pt.pagetemplate`
--------------------------

``PageTemplate*`` constructors create templates from XML
files.

.. automodule:: z3c.pt.pagetemplate

  .. autoclass:: PageTemplate

  .. autoclass:: PageTemplateFile

:mod:`z3c.pt.texttemplate`
--------------------------

``TextTemplate*`` constructors create templates from plaintext
files.

.. automodule:: z3c.pt.texttemplate

  .. autoclass:: TextTemplate

  .. autoclass:: TextTemplateFile

:mod:`z3c.pt.loader`
--------------------------

A template loader class is provided (for use with Pylons and other
platforms).
  
.. automodule:: z3c.pt.loader

  .. autoclass:: TemplateLoader